@@ -7,7 +7,7 @@ use warnings;
 use autodie;
 use namespace::autoclean;
 
-our $VERSION = '0.56';
+our $VERSION = '0.57';
 
 use Dist::Zilla;
 
@@ -492,7 +492,7 @@ sub _explicit_prereq_plugins {
 sub _prompt_if_stale_plugin {
     return [
         'PromptIfStale' => {
-            phase             => 'release',
+            phase             => 'build',
             check_all_plugins => 1,
             check_all_prereqs => 1,
             skip              => [
@@ -711,7 +711,7 @@ Dist::Zilla::PluginBundle::DROLSKY - DROLSKY's plugin bundle
 
 =head1 VERSION
 
-version 0.56
+version 0.57
 
 =head1 DESCRIPTION
 
